@@ -12,9 +12,10 @@ timeStamp = lambda day,time:int(mktime( strptime(day +" "+ time, "%Y-%m-%d %H:%M
        
 class Schedule(xuexitong.Xuexitong):
 
-    def __init__(self):
+    def __init__(self,debug=True):
         
         super(Schedule, self).__init__()
+        self.debug = debug 
 
     def getSchedule(self):
 
@@ -24,7 +25,7 @@ class Schedule(xuexitong.Xuexitong):
 
         return schedule
 
-    def isReserved(self,roomId,day,startTime,endTime,seats={"roomId":"3925","seats":["001"]},**a):
+    def isReserved(self,roomId,day,startTime,endTime,seats={"roomId":"3925","seats":["001"]},debug=False,**a):
         
         # 匹配未被预约的位置
         """
@@ -41,15 +42,16 @@ class Schedule(xuexitong.Xuexitong):
         reservdSeats = res.json().get("data").get("seatNums",[]) 
 
         result = []
-        print("已经被预约的座位号",reservdSeats)
+        if self.debug and not debug: print(day,startTime,"已经被预约的座位号",reservdSeats)
 
         for seat in seats.get("seats"):
+            # print(seat,seat not in reservdSeats , seat not in result)
             if seat not in reservdSeats and seat not in result:
                 data["seatNum"] = seat
                 
                 result.append( data.copy() )
 
-        print("符合需求的座位号",result,"\n")
+        if self.debug and not debug: print(day,startTime,"符合需求的座位号",result,"\n")
 
         return result,reservdSeats
 
@@ -57,24 +59,25 @@ class Schedule(xuexitong.Xuexitong):
         # 暂离
 
         # url = self.baseurl+'/data/apps/seat/leave'
-        url = self.baseurl+"/data/apps/seat/supervisepage"
+        url = "https://office.chaoxing.com/front/third/apps/seat/supervisepage?id=3925&seatNum=041"
         data = {
             "id":roomId,
             "seatNum":seatNum
         }
-        res = self.requests.get(url,params=data)
+        res = self.requests.get(url,params=data,headers={"User-Agent":"mozilla/5.0 (linux; u; android 4.1.2; zh-cn; mi-one plus build/jzo54k) applewebkit/534.30 (khtml, like gecko) version/4.0 mobile safari/534.30 micromessenger/5.0.1.352  "})
 
         result = res.json()
-        print("正在监督。。。。。",result)
+        if self.debug: print("正在监督。。。。。",result)
 
 if __name__ == '__main__':
-    Man = Schedule()
-    Man.login()
+    # Man = Schedule()
+    # Man.login()
 
-    schedules = Man.getSchedule()
+    # schedules = Man.getSchedule()
 
-    base = {"day":'2020-09-03',"startTime":'8:00',"endTime":'11:30' }
-    for i in schedules:
-        base["seats"] = i
-        base["roomId"] = i.get("roomId")
-        Man.isReserved(**base)
+    # base = {"day":'2020-09-03',"startTime":'8:00',"endTime":'11:30' }
+    # for i in schedules:
+    #     base["seats"] = i
+    #     base["roomId"] = i.get("roomId")
+    #     Man.isReserved(**base)
+    pass
\ No newline at end of file
